@@ -383,7 +383,8 @@ impl<'a, I: Tokens> Parser<I> {
                 let arg = Pat::from(ident);
                 let params = vec![arg];
                 expect!(self, "=>");
-                let body = self.parse_fn_body(true, false, params.is_simple_parameter_list())?;
+                let body =
+                    self.parse_fn_body(true, false, true, params.is_simple_parameter_list())?;
 
                 return Ok(Box::new(Expr::Arrow(ArrowExpr {
                     span: span!(self, start),
@@ -396,7 +397,8 @@ impl<'a, I: Tokens> Parser<I> {
                 })));
             } else if can_be_arrow && !self.input.had_line_break_before_cur() && eat!(self, "=>") {
                 let params = vec![id.into()];
-                let body = self.parse_fn_body(false, false, params.is_simple_parameter_list())?;
+                let body =
+                    self.parse_fn_body(false, false, true, params.is_simple_parameter_list())?;
 
                 return Ok(Box::new(Expr::Arrow(ArrowExpr {
                     span: span!(self, start),
@@ -664,10 +666,12 @@ impl<'a, I: Tokens> Parser<I> {
             is_direct_child_of_cond: false,
             ..self.ctx()
         };
+
         let paren_items = self
             .with_ctx(ctx)
             .include_in_expr(true)
             .parse_args_or_pats()?;
+
         let has_pattern = paren_items
             .iter()
             .any(|item| matches!(item, PatOrExprOrSpread::Pat(..)));
@@ -675,7 +679,11 @@ impl<'a, I: Tokens> Parser<I> {
         let is_direct_child_of_cond = self.ctx().is_direct_child_of_cond;
 
         // This is slow path. We handle arrow in conditional expression.
-        if self.syntax().typescript() && self.ctx().in_cond_expr && is!(self, ':') {
+        if self.syntax().typescript()
+            && self.ctx().in_cond_expr
+            && !self.ctx().in_arrow_function
+            && is!(self, ':')
+        {
             // TODO: Remove clone
             let items_ref = &paren_items;
             if let Some(expr) = self.try_parse_ts(|p| {
@@ -691,6 +699,7 @@ impl<'a, I: Tokens> Parser<I> {
                 let body: BlockStmtOrExpr = p.parse_fn_body(
                     async_span.is_some(),
                     false,
+                    true,
                     params.is_simple_parameter_list(),
                 )?;
 
@@ -745,6 +754,7 @@ impl<'a, I: Tokens> Parser<I> {
             let body: BlockStmtOrExpr = self.parse_fn_body(
                 async_span.is_some(),
                 false,
+                true,
                 params.is_simple_parameter_list(),
             )?;
             let arrow_expr = ArrowExpr {
@@ -1705,7 +1715,7 @@ impl<'a, I: Tokens> Parser<I> {
                     .collect();
 
                 let body: BlockStmtOrExpr =
-                    self.parse_fn_body(false, false, params.is_simple_parameter_list())?;
+                    self.parse_fn_body(false, false, true, params.is_simple_parameter_list())?;
                 let span = span!(self, start);
 
                 items.push(PatOrExprOrSpread::ExprOrSpread(ExprOrSpread {
